<?php

class IndexController extends pm_Controller_Action {

    public function indexAction() {
        if(file_exists('/var/awp/bin/aum')) {
			$this->_forward('dashBoard');
		} else {
			$form = new pm_Form_Simple();
			$form->addControlButtons([
				'sendTitle' => 'Install AUM',
				'cancelHidden' => true,
				'hideLegend'   => true,
			]);

			if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
				$this->_helper->json(['redirect' => pm_Context::getActionUrl('index','eula')]);
			}
			$this->view->headLink()->appendStylesheet(pm_Context::getBaseUrl() . 'index.css');
			$this->view->form = $form;
		}
    }
	public function dashboardAction() {
		$this->view->headLink()->appendStylesheet(pm_Context::getBaseUrl() . 'dash-board.css');
	}

	public function eulaAction() {
		$this->view->headLink()->appendStylesheet(pm_Context::getBaseUrl() . 'eula.css');
		$this->view->headScript()->appendFile(pm_Context::getBaseUrl() . 'eula.js');
		$form = new pm_Form_Simple();
		$form->addControlButtons([
			'sendTitle' => 'Submit',
			'cancelHidden' => false,
			'hideLegend'   => true,
		]);

		if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
			$this->_helper->json(['redirect' => pm_Context::getActionUrl('index','download')]);
		}

		$this->view->form = $form;
	}

	public function downloadAction() {
		$this->view->headLink()->appendStylesheet(pm_Context::getBaseUrl() . 'download.css');
		$this->view->headScript()->appendFile(pm_Context::getBaseUrl() . 'download.js');
		$testing_flag = FALSE;
		$l = $this->_get_license();
		if ( ($l["expired"] && $l["product"] != "free-waf" )) {
			$this->view->licenseExpired = TRUE;
			$this->view->buy_url=pm_Context::getBuyUrl();
		} else {
			$this->view->licenseExpired = FALSE;
			$form = new pm_Form_Simple();
			$form->addElement("text", "username",['required' => 'true']);
			$form->addElement("password", "password",['required' => 'true']);
			$form->addElement("password", "password2", ['required' => 'true']);
			$form->addControlButtons([
				'sendTitle' => 'Submit',
				'cancelHidden' => FALSE,
				'hideLegend'   => TRUE,
			]);
			if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
				$formValues = $form->getValues();
				if ($formValues['password'] != $formValues['password2']) {
					$this->_status->addMessage('error', "indexController:downloadAction:error - Password fields must match.");
					$this->_helper->json(['redirect' => pm_Context::getActionUrl('index','download')]);
				} else {
					$this->_helper->json(
						[
							'redirect' => pm_Context::getActionUrl('index','install'),
							'postData' => [
								'user' => $formValues['username'],
								'pass' => $formValues['password'],
							]
						]);
				}
			}
		}
		$this->view->form = $form;
	}

	public function installAction() {
		$feed_source = "";
		$ok=FALSE;
		$license_info = $this->_get_license();
		$this->view->headLink()->appendStylesheet(pm_Context::getBaseUrl() . 'install.css');
		$this->view->headScript()->appendFile(pm_Context::getBaseUrl() . 'install.js');
		if (!$license_info["key_err"]) {
			$this->view->licenseExist="true";
			$ok=TRUE;
			switch ($license_info["product"]) {
				case "52":
				case "54":
					$feed_source="subscription";
					break;
				default:
					$feed_source="free-waf";
					break;
			}
		} else {
			$this->_status->addMessage('error', "indexController:installAction:error - License information returned error.");
			$this->_helper->json(['redirect' => pm_Context::getActionUrl('index','download')]);
		}

		if (!$ok) {
			$this->view->licenseExist="false";
			$this->_status->addMessage('error', "indexController:installAction:error - Failed to validate license type.");
			$this->_helper->json(['redirect' => pm_Context::getActionUrl('index','download')]);
		} else {
			$User = $this->getRequest()->getPost('user');
			$Password = $this->getRequest()->getPost('pass');
			$this->taskManager = new pm_LongTask_Manager();
			$task = new Modules_AumInstaller_Install();
			$task->Init($User,$Password,$feed_source);
			$this->taskManager->start($task);
		}
	}


	public function _get_license() {
		$license_path = "/var/awp/etc/license.key";
		$ret=array(
			"expired"	=> FALSE,
			"product" => "free-waf",
			"key_err" => FALSE,
		);
		$get_input=FALSE;
		$license=pm_License::getAdditionalKey("aum-installer");
		if (file_exists($license_path)) {
			if ($f=file_get_contents($license_path)) {
				if ($d=base64_decode($f)) {
					if ($lk=unserialize($d)) {
						if (isset($lk["login"]) && isset($lk["pass"]) && isset($lk["product"])) {
							$this->view->licenseExist="true";
							$ret["product"] = $lk["product"];
						} else {
							$ret["key_err"] = TRUE;
						}
					}
				}
			}
		} else if ($license !== null) {
			$license=reset($license);
			$body=$license["key-body"];
			$ts_expire=strtotime($license["lim_date"]);
			if ($ts_expire<time()) {
				$ret["expired"]=TRUE;
			} else {
				$lk = unserialize(base64_decode(trim($body)));
				if ( isset($lk["login"]) && isset($lk["pass"]) && isset($lk["product"]) ) {
					if (!file_exists($license_path)) {
						pm_ApiCli::callSbin('license_build.sh', trim($body));
					}
					$ret["product"] = $lk["product"];
				} else {
					$ret["key_err"] = TRUE;
				}
			}
		}  else {
			$ch=curl_init();
			curl_setopt($ch,CURLOPT_URL,"https://www.atomicorp.com/pisv_u/isv_u.php");
			curl_setopt($ch,CURLOPT_SSL_VERIFYPEER,FALSE);
			curl_setopt($ch,CURLOPT_RETURNTRANSFER,TRUE);
			curl_setopt($ch,CURLOPT_FORBID_REUSE,TRUE);
			curl_setopt($ch,CURLOPT_FRESH_CONNECT,TRUE);
			curl_setopt($ch,CURLOPT_USERAGENT,"Atomic Updater Modified (6.0)");
			curl_setopt($ch,CURLOPT_POST,TRUE);
			curl_setopt($ch,CURLOPT_POSTFIELDS,"acaumext=1");
			$response=@curl_exec($ch);
			if ($http_status=curl_getinfo($ch,CURLINFO_HTTP_CODE)) {
				if ($http_status=="200") {
				   $ok=TRUE;
					$f=@trim($response);
					if (!file_exists($license_path)) {
						pm_ApiCli::callSbin('license_build.sh', [$f]);
					}
				} else {
					$ret["key_err"] = TRUE;
				   $this->_status->addMessage('error', "indexController:installAction:error - Failed to download failsafe global free rules: ".$http_status);
				   $this->_helper->json(['redirect' => pm_Context::getActionUrl('index','download')]);
				}
			}
		}
		return $ret;
	}
}
